==> composer_2.3.8.orig.tar.xz: composer-2.3.8/tests/Composer/Test/DependencyResolver/PoolTest.php <==
<?php declare(strict_types=1);

/*
 * This file is part of Composer.
 *
 * (c) Nils Adermann <naderman@naderman.de>
 *     Jordi Boggiano <j.boggiano@seld.be>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Composer\Test\DependencyResolver;

use Composer\DependencyResolver\Pool;
use Composer\Test\TestCase;

class PoolTest extends TestCase
{
    public function testPool(): void
    {
        $package = $this->getPackage('foo', '1');

        $pool = $this->createPool(array($package));

        $this->assertEquals(array($package), $pool->whatProvides('foo'));
        $this->assertEquals(array($package), $pool->whatProvides('foo'));
    }

    public function testWhatProvidesPackageWithConstraint(): void
    {
        $firstPackage = $this->getPackage('foo', '1');
        $secondPackage = $this->getPackage('foo', '2');

        $pool = $this->createPool(array(
            $firstPackage,
            $secondPackage,
        ));

        $this->assertEquals(array($firstPackage, $secondPackage), $pool->whatProvides('foo'));
        $this->assertEquals(array($secondPackage), $pool->whatProvides('foo', $this->getVersionConstraint('==', '2')));
    }

    public function testPackageById(): void
    {
        $package = $this->getPackage('foo', '1');

        $pool = $this->createPool(array($package));

        $this->assertSame($package, $pool->packageById(1));
    }

    public function testWhatProvidesWhenPackageCannotBeFound(): void
    {
        $pool = $this->createPool();

        $this->assertEquals(array(), $pool->whatProvides('foo'));
    }

    /**
     * @param array<\Composer\Package\BasePackage>|null $packages
     * @return \Composer\DependencyResolver\Pool
     */
    protected function createPool(?array $packages = array()): Pool
    {
        return new Pool($packages);
    }
}

==> composer_2.4.1.orig.tar.xz: composer-2.4.1/tests/Composer/Test/DependencyResolver/PoolTest.php <==
<?php declare(strict_types=1);

/*
 * This file is part of Composer.
 *
 * (c) Nils Adermann <naderman@naderman.de>
 *     Jordi Boggiano <j.boggiano@seld.be>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Composer\Test\DependencyResolver;

use Composer\DependencyResolver\Pool;
use Composer\Test\TestCase;

class PoolTest extends TestCase
{
    public function testPool(): void
    {
        $package = $this->getPackage('foo', '1');

        $pool = $this->createPool([$package]);

        $this->assertEquals([$package], $pool->whatProvides('foo'));
        $this->assertEquals([$package], $pool->whatProvides('foo'));
    }

    public function testWhatProvidesPackageWithConstraint(): void
    {
        $firstPackage = $this->getPackage('foo', '1');
        $secondPackage = $this->getPackage('foo', '2');

        $pool = $this->createPool([
            $firstPackage,
            $secondPackage,
        ]);

        $this->assertEquals([$firstPackage, $secondPackage], $pool->whatProvides('foo'));
        $this->assertEquals([$secondPackage], $pool->whatProvides('foo', $this->getVersionConstraint('==', '2')));
    }

    public function testPackageById(): void
    {
        $package = $this->getPackage('foo', '1');

        $pool = $this->createPool([$package]);

        $this->assertSame($package, $pool->packageById(1));
    }

    public function testWhatProvidesWhenPackageCannotBeFound(): void
    {
        $pool = $this->createPool();

        $this->assertEquals([], $pool->whatProvides('foo'));
    }

    /**
     * @param array<\Composer\Package\BasePackage>|null $packages
     */
    protected function createPool(?array $packages = []): Pool
    {
        return new Pool($packages);
    }
}
